PlodiaRBFSfamly), date of egg laying (date_laid) and assaying
(date_Ass), and a binary variable indicating whether an individual was
resistant (Pupated) to an experimental infection of the virus. These data
are identical to those in the data.frame PlodiaR except each family-level
binomial variable has been expanded into a binary variable for each individual.