Krzanowski's Comparison of Subspaces
krzanowski.test.RdCalculates statistics of Krzanowski's comparison of subspaces.
Value
- sumofS
metric for overall similarity with 0 indicting no similarity and a value of
length(vecsA)for identical subspaces- angles
angle in degrees between each best matched pair of vectors
- bisector
vector that lies between each best matched pair of vectors
Author
Jarrod Hadfield j.hadfield@ed.ac.uk
Examples
CA<-rIW(diag(5),10, n=1)
CB<-rIW(diag(5),10, n=1)
krzanowski.test(CA, CB, vecsA=1:2, vecsB=1:2)
#> $sumofS
#> [1] 0.9271759
#>
#> $angles
#> [1] 27.20786 68.34061
#>
#> $bisector
#> [,1] [,2]
#> [1,] -0.1983429 0.39576182
#> [2,] -0.1027287 0.87848379
#> [3,] 0.4895669 -0.08465776
#> [4,] -0.8353376 -0.25352035
#> [5,] -0.1124375 0.01411782
#>
krzanowski.test(CA, CA, vecsA=1:2, vecsB=1:2)
#> $sumofS
#> [1] 2
#>
#> $angles
#> [1] 0.000000e+00 2.414837e-06
#>
#> $bisector
#> [,1] [,2]
#> [1,] -0.11139250 -0.17180159
#> [2,] -0.29473597 0.94471840
#> [3,] 0.59439347 0.13845887
#> [4,] -0.73728596 -0.23506839
#> [5,] 0.06187279 0.05969375
#>