Design Matrix for Path Analyses
path.RdForms design matrix for path analyses that involve paths within residual blocks
Note
For more general path anlaytic models see sir which allows paths to exist between responses that are not in the same residual block. However, sir does not handle non-Gaussian or missing responses. Note that path models involving non-Gaussian data are defined on the link scale which may not always be appropriate.
Author
Jarrod Hadfield j.hadfield@ed.ac.uk