Tensor of (mixed) partial derivatives
Dtensor.RdForms tensor of (mixed) partial derivatives
Arguments
- expr
'expression'
- name
character vector, giving the variable names with respect to which derivatives will be computed. If NULL all variables in the expression will be used
- mu
optional: numeric vector, at which the derivatives are evaluated
- m
order of derivative
- evaluate
logical; if
TRUEthe derivatives are evaluated atmu, ifFALSEthe derivatives are left unevaluated
References
Rice, S.H. (2004) Evolutionary Theory: Mathematical and Conceptual Foundations. Sinauer (MA) USA.
Examples
f<-expression(beta_1 + time * beta_2 + u)
Dtensor(f,eval=FALSE)
#> [[1]]
#> [1] 1
#>
#> [[2]]
#> beta_2
#>
#> [[3]]
#> time
#>
#> [[4]]
#> [1] 1
#>