Design Matrix for Measurement Error Model
me.RdSets up design matrix for measurement error models.
Arguments
- formula
formulafor the fixed effects.- error
character; name of column in
data.framein which standard error (type="classical"ortype="berkson") or miscalssification error (type="dclassical") is stored.- group
name of column in
data.framein which groups are stored. Rows of the design matrix with the samegrouplevel are assumed to pertain to the same obsevation of the covariate that is measured with error.- type
character; one of
type="classical",type="berkson",type="dclassical"ortype="dberkson"(see details)
Author
Jarrod Hadfield j.hadfield@ed.ac.uk