Learn R Programming

MCMCglmm (version 1.06)

posterior.mode: Estimates the mode of a vector using kernel density estimation

Description

Estimates the mode of a vector using kernel density estimation

Usage

posterior.mode(x)

Arguments

x
numeric vector

Value

  • mode of the kernel density estimate

See Also

density

Examples

Run this code
v<-rIW(10, as.matrix(1), n=1000)
hist(v)
abline(v=posterior.mode(v), col="red")

Run the code above in your browser using DataLab